Figure out gene locations to make room for gene names. Written original by Dan Gatti 2013-02-13
get.gene.locations(
locs,
xlim,
text_size = 3,
str_rect = c("iW", "i"),
n_rows = 10,
plot_width = 6,
...
)list object used by ggplot_feature_tbl
tbl of gene information
X axis limits
size of text (default 3)
character spacing on left and right of rectangles (default c("iW","i"))
desired number of rows (default 10)
width of default plot window (in inches)
additional parameters (not used)
Brian S Yandell, brian.yandell@wisc.edu Daniel Gatti, Dan.Gatti@jax.org