Show count min and max of features by type
Plot genes as rectangles followed by names. Stagger genes for easy reading. Written original by Dan Gatti 2013-02-13
# S3 method for feature_tbl
summary(object, major = TRUE, ...)# S3 method for feature_tbl
subset(x, start_val = 0, stop_val = max(x$stop), ...)
ggplot_feature_tbl(
object,
rect_col = "grey70",
strand_col = c(`-` = "#1b9e77", `+` = "#d95f02"),
type_col = c(gene = "black", pseudogene = "#1b9e77", other = "#d95f02"),
text_size = 3,
xlim = NULL,
snp_pos = top_snps_tbl$pos,
snp_lod = top_snps_tbl$lod,
top_snps_tbl = NULL,
snp_col = "grey70",
extend = 0.005,
...
)
# S3 method for feature_tbl
autoplot(object, ...)
tbl of feature summaries by type
tbl of feature summaries by type
data frame of gene information (invisible)
tbl of gene information from query_variants; see create_variant_query_func
if TRUE (default), only summarize genes and exons
additional arguments (not used)
tbl of feature information from get_feature_snp
start and stop positions for subset
fill color of rectangle (default "grey70")
edge color of rectangle by strand from object (default -="blue", +="red"; none if NULL)
color of type from object (default "black" for gene, "blue" for pseudogene; none if NULL)
size of text (default 3)
horizontal axis limits (default is range of features)
position of SNPs in bp if used (default NULL)
LOD of SNPs (for color plotting)
table from top_snps
color of SNP vertical lines (default "grey70")
extend region for SNPs in bp (default 0.005)
Brian S Yandell, brian.yandell@wisc.edu
Brian S Yandell, brian.yandell@wisc.edu Daniel Gatti, Dan.Gatti@jax.org